@@ -1,7 +1,10 @@
-#' Check for a function argument.
+#' @title Check for a function argument.
 #'
-#' Throws exception if checks are not passed.
-#' Note that argument is evaluated when checked.
+#' @description
+#' Throws exception if checks are not passed. Note that argument is evaluated when checked.
+#'
+#' This function is superseded by the package \pkg{checkmate} and might get deprecated
+#' in the future. Please
 #'
 #' @param x [any]\cr
 #'   Argument.
@@ -46,19 +49,6 @@
 #'   Default is missing.
 #' @return Nothing.
 #' @export
-#' @examples
-#' x = 1L
-#' checkArg(x, "integer", len = 1, na.ok = FALSE, upper = 3L)
-#' x = as.integer(NA)
-#' checkArg(x, "integer", len = 1, na.ok = TRUE)
-#' x = c("foo", "bar")
-#' checkArg(x, "character")
-#' x = "foo"
-#' checkArg(x, choices = c("foo", "bar"))
-#' x = c("foo", "bar")
-#' checkArg(x, subset = c("foo", "bar"))
-#' fun = function(foo, bar)
-#' checkArg(fun, formals = c("foo", "bar"))
 checkArg = function(x, cl, s4 = FALSE, len, min.len, max.len, choices, subset, lower = NA, upper = NA, na.ok = TRUE, formals) {
   s = deparse(substitute(x))
   if (missing(x))
@@ -101,9 +91,9 @@ checkArg = function(x, cl, s4 = FALSE, len, min.len, max.len, choices, subset, l
       stop("Argument ", s, " must be at most of length ", max.len, " not: ", len2, "!")
     if (!na.ok && any(is.na(x)))
       stop("Argument ", s, " must not contain any NAs!")
-    if (is.numeric(x) && !is.na(lower) && ((is.na(x) && !na.ok) || (!is.na(x) && any(x < lower))))
+    if (is.numeric(x) && !is.na(lower) && ((any(is.na(x)) && !na.ok) || (!any(is.na(x)) && any(x < lower))))
       stop("Argument ", s, " must be greater than or equal ", lower, "!")
-    if (is.numeric(x) && !is.na(upper) && ((is.na(x) && !na.ok) || (!is.na(x) && any(x > upper))))
+    if (is.numeric(x) && !is.na(upper) && ((any(is.na(x)) && !na.ok) || (!any(is.na(x)) && any(x > upper))))
       stop("Argument ", s, " must be less than or equal ", upper, "!")
   }
 }
